@@ -6,8 +6,8 @@ package candidtest
 import (
 	"context"
 
+	"github.com/go-macaroon-bakery/macaroon-bakery/v3/bakery/checkers"
 	errgo "gopkg.in/errgo.v1"
-	"gopkg.in/macaroon-bakery.v3/bakery/checkers"
 )
 
 const candidtestNamespace = "github.com/juju/candidclient/candidtest"
