@@ -4,7 +4,7 @@
 package discharger
 
 import (
-	"gopkg.in/macaroon-bakery.v3/bakery"
+	"github.com/go-macaroon-bakery/macaroon-bakery/v3/bakery"
 
 	"github.com/canonical/candid/internal/auth"
 )
